<?php
// This file was auto-generated from sdk-root/src/data/proton/2020-07-20/docs-2.json
return [ 'version' => '2.0', 'service' => '<p>This is the AWS Proton Service API Reference. It provides descriptions, syntax and usage examples for each of the <a href="https://docs.aws.amazon.com/proton/latest/APIReference/API_Operations.html">actions</a> and <a href="https://docs.aws.amazon.com/proton/latest/APIReference/API_Types.html">data types</a> for the AWS Proton service.</p> <p>The documentation for each action shows the Query API request parameters and the XML response.</p> <p>Alternatively, you can use the AWS CLI to access an API. For more information, see the <a href="https://docs.aws.amazon.com/cli/latest/userguide/cli-chap-welcome.html">AWS Command Line Interface User Guide</a>.</p> <p>The AWS Proton service is a two-pronged automation framework. Administrators create service templates to provide standardized infrastructure and deployment tooling for serverless and container based applications. Developers, in turn, select from the available service templates to automate their application or service deployments.</p> <p>Because administrators define the infrastructure and tooling that AWS Proton deploys and manages, they need permissions to use all of the listed API operations.</p> <p>When developers select a specific infrastructure and tooling set, AWS Proton deploys their applications. To monitor their applications that are running on AWS Proton, developers need permissions to the service <i>create</i>, <i>list</i>, <i>update</i> and <i>delete</i> API operations and the service instance <i>list</i> and <i>update</i> API operations.</p> <p>To learn more about AWS Proton administration, see the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/Welcome.html">AWS Proton Administrator Guide</a>.</p> <p>To learn more about deploying serverless and containerized applications on AWS Proton, see the <a href="https://docs.aws.amazon.com/proton/latest/userguide/Welcome.html">AWS Proton User Guide</a>.</p> <p> <b>Ensuring Idempotency</b> </p> <p>When you make a mutating API request, the request typically returns a result before the asynchronous workflows of the operation are complete. Operations might also time out or encounter other server issues before they\'re complete, even if the request already returned a result. This might make it difficult to determine whether the request succeeded. Moreover, you might need to retry the request multiple times to ensure that the operation completes successfully. However, if the original request and the subsequent retries are successful, the operation occurs multiple times. This means that you might create more resources than you intended.</p> <p> <i>Idempotency</i> ensures that an API request action completes no more than one time. With an idempotent request, if the original request action completes successfully, any subsequent retries complete successfully without performing any further actions. However, the result might contain updated information, such as the current creation status.</p> <p>The following lists of APIs are grouped according to methods that ensure idempotency.</p> <p> <b>Idempotent create APIs with a client token</b> </p> <p>The API actions in this list support idempotency with the use of a <i>client token</i>. The corresponding AWS CLI commands also support idempotency using a client token. A client token is a unique, case-sensitive string of up to 64 ASCII characters. To make an idempotent API request using one of these actions, specify a client token in the request. We recommend that you <i>don\'t</i> reuse the same client token for other API requests. If you don’t provide a client token for these APIs, a default client token is automatically provided by SDKs.</p> <p>Given a request action that has succeeded:</p> <p>If you retry the request using the same client token and the same parameters, the retry succeeds without performing any further actions other than returning the original resource detail data in the response.</p> <p>If you retry the request using the same client token, but one or more of the parameters are different, the retry throws a <code>ValidationException</code> with an <code>IdempotentParameterMismatch</code> error.</p> <p>Client tokens expire eight hours after a request is made. If you retry the request with the expired token, a new resource is created.</p> <p>If the original resource is deleted and you retry the request, a new resource is created.</p> <p>Idempotent create APIs with a client token:</p> <ul> <li> <p>CreateEnvironmentTemplateVersion</p> </li> <li> <p>CreateServiceTemplateVersion</p> </li> <li> <p>CreateEnvironmentAccountConnection</p> </li> </ul> <p> <b>Idempotent create APIs</b> </p> <p>Given a request action that has succeeded:</p> <p>If you retry the request with an API from this group, and the original resource <i>hasn\'t</i> been modified, the retry succeeds without performing any further actions other than returning the original resource detail data in the response.</p> <p>If the original resource has been modified, the retry throws a <code>ConflictException</code>.</p> <p>If you retry with different input parameters, the retry throws a <code>ValidationException</code> with an <code>IdempotentParameterMismatch</code> error.</p> <p>Idempotent create APIs:</p> <ul> <li> <p>CreateEnvironmentTemplate</p> </li> <li> <p>CreateServiceTemplate</p> </li> <li> <p>CreateEnvironment</p> </li> <li> <p>CreateService</p> </li> </ul> <p> <b>Idempotent delete APIs</b> </p> <p>Given a request action that has succeeded:</p> <p>When you retry the request with an API from this group and the resource was deleted, its metadata is returned in the response.</p> <p>If you retry and the resource doesn\'t exist, the response is empty.</p> <p>In both cases, the retry succeeds.</p> <p>Idempotent delete APIs:</p> <ul> <li> <p>DeleteEnvironmentTemplate</p> </li> <li> <p>DeleteEnvironmentTemplateVersion</p> </li> <li> <p>DeleteServiceTemplate</p> </li> <li> <p>DeleteServiceTemplateVersion</p> </li> <li> <p>DeleteEnvironmentAccountConnection</p> </li> </ul> <p> <b>Asynchronous idempotent delete APIs</b> </p> <p>Given a request action that has succeeded:</p> <p>If you retry the request with an API from this group, if the original request delete operation status is <code>DELETE_IN_PROGRESS</code>, the retry returns the resource detail data in the response without performing any further actions.</p> <p>If the original request delete operation is complete, a retry returns an empty response.</p> <p>Asynchronous idempotent delete APIs:</p> <ul> <li> <p>DeleteEnvironment</p> </li> <li> <p>DeleteService</p> </li> </ul>', 'operations' => [ 'AcceptEnvironmentAccountConnection' => '<p>In a management account, an environment account connection request is accepted. When the environment account connection request is accepted, AWS Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account.</p> <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html">Environment account connections</a> in the <i>AWS Proton Administrator guide</i>.</p>', 'CancelEnvironmentDeployment' => '<p>Attempts to cancel an environment deployment on an <a>UpdateEnvironment</a> action, if the deployment is <code>IN_PROGRESS</code>. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-update.html">Update an environment</a> in the <i>AWS Proton Administrator guide</i>.</p> <p>The following list includes potential cancellation scenarios.</p> <ul> <li> <p>If the cancellation attempt succeeds, the resulting deployment state is <code>CANCELLED</code>.</p> </li> <li> <p>If the cancellation attempt fails, the resulting deployment state is <code>FAILED</code>.</p> </li> <li> <p>If the current <a>UpdateEnvironment</a> action succeeds before the cancellation attempt starts, the resulting deployment state is <code>SUCCEEDED</code> and the cancellation attempt has no effect.</p> </li> </ul>', 'CancelServiceInstanceDeployment' => '<p>Attempts to cancel a service instance deployment on an <a>UpdateServiceInstance</a> action, if the deployment is <code>IN_PROGRESS</code>. For more information, see <i>Update a service instance</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-svc-instance-update.html">AWS Proton Administrator guide</a> or the <a href="https://docs.aws.amazon.com/proton/latest/userguide/ug-svc-instance-update.html">AWS Proton User guide</a>.</p> <p>The following list includes potential cancellation scenarios.</p> <ul> <li> <p>If the cancellation attempt succeeds, the resulting deployment state is <code>CANCELLED</code>.</p> </li> <li> <p>If the cancellation attempt fails, the resulting deployment state is <code>FAILED</code>.</p> </li> <li> <p>If the current <a>UpdateServiceInstance</a> action succeeds before the cancellation attempt starts, the resulting deployment state is <code>SUCCEEDED</code> and the cancellation attempt has no effect.</p> </li> </ul>', 'CancelServicePipelineDeployment' => '<p>Attempts to cancel a service pipeline deployment on an <a>UpdateServicePipeline</a> action, if the deployment is <code>IN_PROGRESS</code>. For more information, see <i>Update a service pipeline</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-svc-pipeline-update.html">AWS Proton Administrator guide</a> or the <a href="https://docs.aws.amazon.com/proton/latest/userguide/ug-svc-pipeline-update.html">AWS Proton User guide</a>.</p> <p>The following list includes potential cancellation scenarios.</p> <ul> <li> <p>If the cancellation attempt succeeds, the resulting deployment state is <code>CANCELLED</code>.</p> </li> <li> <p>If the cancellation attempt fails, the resulting deployment state is <code>FAILED</code>.</p> </li> <li> <p>If the current <a>UpdateServicePipeline</a> action succeeds before the cancellation attempt starts, the resulting deployment state is <code>SUCCEEDED</code> and the cancellation attempt has no effect.</p> </li> </ul>', 'CreateEnvironment' => '<p>Deploy a new environment. An AWS Proton environment is created from an environment template that defines infrastructure and resources that can be shared across services. For more information, see the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-environments.html">Environments</a> in the <i>AWS Proton Administrator Guide.</i> </p>', 'CreateEnvironmentAccountConnection' => '<p>Create an environment account connection in an environment account so that environment infrastructure resources can be provisioned in the environment account from a management account.</p> <p>An environment account connection is a secure bi-directional connection between a <i>management account</i> and an <i>environment account</i> that maintains authorization and permissions. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html">Environment account connections</a> in the <i>AWS Proton Administrator guide</i>.</p>', 'CreateEnvironmentTemplate' => '<p>Create an environment template for AWS Proton. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-templates.html">Environment Templates</a> in the <i>AWS Proton Administrator Guide</i>.</p> <p>You can create an environment template in one of the two following ways:</p> <ul> <li> <p>Register and publish a <i>standard</i> environment template that instructs AWS Proton to deploy and manage environment infrastructure.</p> </li> <li> <p>Register and publish a <i>customer managed</i> environment template that connects AWS Proton to your existing provisioned infrastructure that you manage. AWS Proton <i>doesn\'t</i> manage your existing provisioned infrastructure. To create an environment template for customer provisioned and managed infrastructure, include the <code>provisioning</code> parameter and set the value to <code>CUSTOMER_MANAGED</code>. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/template-create.html">Register and publish an environment template</a> in the <i>AWS Proton Administrator Guide</i>.</p> </li> </ul>', 'CreateEnvironmentTemplateVersion' => '<p>Create a new major or minor version of an environment template. A major version of an environment template is a version that <i>isn\'t</i> backwards compatible. A minor version of an environment template is a version that\'s backwards compatible within its major version.</p>', 'CreateService' => '<p>Create an AWS Proton service. An AWS Proton service is an instantiation of a service template and often includes several service instances and pipeline. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-services.html">Services</a> in the <i>AWS Proton Administrator Guide</i> and <a href="https://docs.aws.amazon.com/proton/latest/userguide/ug-service.html">Services</a> in the <i>AWS Proton User Guide</i>.</p>', 'CreateServiceTemplate' => '<p>Create a service template. The administrator creates a service template to define standardized infrastructure and an optional CICD service pipeline. Developers, in turn, select the service template from AWS Proton. If the selected service template includes a service pipeline definition, they provide a link to their source code repository. AWS Proton then deploys and manages the infrastructure defined by the selected service template. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/managing-svc-templates.html">Service Templates</a> in the <i>AWS Proton Administrator Guide</i>.</p>', 'CreateServiceTemplateVersion' => '<p>Create a new major or minor version of a service template. A major version of a service template is a version that <i>isn\'t</i> backwards compatible. A minor version of a service template is a version that\'s backwards compatible within its major version.</p>', 'DeleteEnvironment' => '<p>Delete an environment.</p>', 'DeleteEnvironmentAccountConnection' => '<p>In an environment account, delete an environment account connection.</p> <p>After you delete an environment account connection that’s in use by an AWS Proton environment, AWS Proton <i>can’t</i> manage the environment infrastructure resources until a new environment account connection is accepted for the environment account and associated environment. You\'re responsible for cleaning up provisioned resources that remain without an environment connection.</p> <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html">Environment account connections</a> in the <i>AWS Proton Administrator guide</i>.</p>', 'DeleteEnvironmentTemplate' => '<p>If no other major or minor versions of an environment template exist, delete the environment template.</p>', 'DeleteEnvironmentTemplateVersion' => '<p>If no other minor versions of an environment template exist, delete a major version of the environment template if it\'s not the <code>Recommended</code> version. Delete the <code>Recommended</code> version of the environment template if no other major versions or minor versions of the environment template exist. A major version of an environment template is a version that\'s not backwards compatible.</p> <p>Delete a minor version of an environment template if it <i>isn\'t</i> the <code>Recommended</code> version. Delete a <code>Recommended</code> minor version of the environment template if no other minor versions of the environment template exist. A minor version of an environment template is a version that\'s backwards compatible.</p>', 'DeleteService' => '<p>Delete a service.</p>', 'DeleteServiceTemplate' => '<p>If no other major or minor versions of the service template exist, delete the service template.</p>', 'DeleteServiceTemplateVersion' => '<p>If no other minor versions of a service template exist, delete a major version of the service template if it\'s not the <code>Recommended</code> version. Delete the <code>Recommended</code> version of the service template if no other major versions or minor versions of the service template exist. A major version of a service template is a version that <i>isn\'t</i> backwards compatible.</p> <p>Delete a minor version of a service template if it\'s not the <code>Recommended</code> version. Delete a <code>Recommended</code> minor version of the service template if no other minor versions of the service template exist. A minor version of a service template is a version that\'s backwards compatible.</p>', 'GetAccountSettings' => '<p>Get detail data for the AWS Proton pipeline service role.</p>', 'GetEnvironment' => '<p>Get detail data for an environment.</p>', 'GetEnvironmentAccountConnection' => '<p>In an environment account, view the detail data for an environment account connection.</p> <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html">Environment account connections</a> in the <i>AWS Proton Administrator guide</i>.</p>', 'GetEnvironmentTemplate' => '<p>Get detail data for an environment template.</p>', 'GetEnvironmentTemplateVersion' => '<p>View detail data for a major or minor version of an environment template.</p>', 'GetService' => '<p>Get detail data for a service.</p>', 'GetServiceInstance' => '<p>Get detail data for a service instance. A service instance is an instantiation of service template, which is running in a specific environment.</p>', 'GetServiceTemplate' => '<p>Get detail data for a service template.</p>', 'GetServiceTemplateVersion' => '<p>View detail data for a major or minor version of a service template.</p>', 'ListEnvironmentAccountConnections' => '<p>View a list of environment account connections.</p> <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html">Environment account connections</a> in the <i>AWS Proton Administrator guide</i>.</p>', 'ListEnvironmentTemplateVersions' => '<p>List major or minor versions of an environment template with detail data.</p>', 'ListEnvironmentTemplates' => '<p>List environment templates.</p>', 'ListEnvironments' => '<p>List environments with detail data summaries.</p>', 'ListServiceInstances' => '<p>List service instances with summaries of detail data.</p>', 'ListServiceTemplateVersions' => '<p>List major or minor versions of a service template with detail data.</p>', 'ListServiceTemplates' => '<p>List service templates with detail data.</p>', 'ListServices' => '<p>List services with summaries of detail data.</p>', 'ListTagsForResource' => '<p>List tags for a resource. For more information, see <i>AWS Proton resources and tagging</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/resources.html">AWS Proton Administrator Guide</a> or <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">AWS Proton User Guide</a>.</p>', 'RejectEnvironmentAccountConnection' => '<p>In a management account, reject an environment account connection from another environment account.</p> <p>After you reject an environment account connection request, you <i>won’t</i> be able to accept or use the rejected environment account connection.</p> <p>You <i>can’t</i> reject an environment account connection that is connected to an environment.</p> <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html">Environment account connections</a> in the <i>AWS Proton Administrator guide</i>.</p>', 'TagResource' => '<p>Tag a resource. For more information, see <i>AWS Proton resources and tagging</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/resources.html">AWS Proton Administrator Guide</a> or <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">AWS Proton User Guide</a>.</p>', 'UntagResource' => '<p>Remove a tag from a resource. For more information, see <i>AWS Proton resources and tagging</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/resources.html">AWS Proton Administrator Guide</a> or <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">AWS Proton User Guide</a>.</p>', 'UpdateAccountSettings' => '<p>Update the AWS Proton pipeline service account settings.</p>', 'UpdateEnvironment' => '<p>Update an environment.</p> <p>If the environment is associated with an environment account connection, <i>don\'t</i> update or include the <code>protonServiceRoleArn</code> parameter to update or connect to an environment account connection. </p> <p>You can only update to a new environment account connection if it was created in the same environment account that the current environment account connection was created in and is associated with the current environment.</p> <p>If the environment <i>isn\'t</i> associated with an environment account connection, <i>don\'t</i> update or include the <code>environmentAccountConnectionId</code> parameter to update or connect to an environment account connection.</p> <p>You can update either the <code>environmentAccountConnectionId</code> or <code>protonServiceRoleArn</code> parameter and value. You can’t update both.</p> <p>There are four modes for updating an environment as described in the following. The <code>deploymentType</code> field defines the mode.</p> <dl> <dt/> <dd> <p> <code>NONE</code> </p> <p>In this mode, a deployment <i>doesn\'t</i> occur. Only the requested metadata parameters are updated.</p> </dd> <dt/> <dd> <p> <code>CURRENT_VERSION</code> </p> <p>In this mode, the environment is deployed and updated with the new spec that you provide. Only requested parameters are updated. <i>Don’t</i> include minor or major version parameters when you use this <code>deployment-type</code>.</p> </dd> <dt/> <dd> <p> <code>MINOR_VERSION</code> </p> <p>In this mode, the environment is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.</p> </dd> <dt/> <dd> <p> <code>MAJOR_VERSION</code> </p> <p>In this mode, the environment is deployed and updated with the published, recommended (latest) major and minor version of the current template, by default. You can also specify a different major version that\'s higher than the major version in use and a minor version (optional).</p> </dd> </dl>', 'UpdateEnvironmentAccountConnection' => '<p>In an environment account, update an environment account connection to use a new IAM role.</p> <p>For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html">Environment account connections</a> in the <i>AWS Proton Administrator guide</i>.</p>', 'UpdateEnvironmentTemplate' => '<p>Update an environment template.</p>', 'UpdateEnvironmentTemplateVersion' => '<p>Update a major or minor version of an environment template.</p>', 'UpdateService' => '<p>Edit a service description or use a spec to add and delete service instances.</p> <note> <p>Existing service instances and the service pipeline <i>can\'t</i> be edited using this API. They can only be deleted.</p> </note> <p>Use the <code>description</code> parameter to modify the description.</p> <p>Edit the <code>spec</code> parameter to add or delete instances.</p>', 'UpdateServiceInstance' => '<p>Update a service instance.</p> <p>There are four modes for updating a service instance as described in the following. The <code>deploymentType</code> field defines the mode.</p> <dl> <dt/> <dd> <p> <code>NONE</code> </p> <p>In this mode, a deployment <i>doesn\'t</i> occur. Only the requested metadata parameters are updated.</p> </dd> <dt/> <dd> <p> <code>CURRENT_VERSION</code> </p> <p>In this mode, the service instance is deployed and updated with the new spec that you provide. Only requested parameters are updated. <i>Don’t</i> include minor or major version parameters when you use this <code>deployment-type</code>.</p> </dd> <dt/> <dd> <p> <code>MINOR_VERSION</code> </p> <p>In this mode, the service instance is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.</p> </dd> <dt/> <dd> <p> <code>MAJOR_VERSION</code> </p> <p>In this mode, the service instance is deployed and updated with the published, recommended (latest) major and minor version of the current template, by default. You can also specify a different major version that is higher than the major version in use and a minor version (optional).</p> </dd> </dl>', 'UpdateServicePipeline' => '<p>Update the service pipeline.</p> <p>There are four modes for updating a service pipeline as described in the following. The <code>deploymentType</code> field defines the mode.</p> <dl> <dt/> <dd> <p> <code>NONE</code> </p> <p>In this mode, a deployment <i>doesn\'t</i> occur. Only the requested metadata parameters are updated.</p> </dd> <dt/> <dd> <p> <code>CURRENT_VERSION</code> </p> <p>In this mode, the service pipeline is deployed and updated with the new spec that you provide. Only requested parameters are updated. <i>Don’t</i> include minor or major version parameters when you use this <code>deployment-type</code>.</p> </dd> <dt/> <dd> <p> <code>MINOR_VERSION</code> </p> <p>In this mode, the service pipeline is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.</p> </dd> <dt/> <dd> <p> <code>MAJOR_VERSION</code> </p> <p>In this mode, the service pipeline is deployed and updated with the published, recommended (latest) major and minor version of the current template by default. You can also specify a different major version that is higher than the major version in use and a minor version (optional).</p> </dd> </dl>', 'UpdateServiceTemplate' => '<p>Update a service template.</p>', 'UpdateServiceTemplateVersion' => '<p>Update a major or minor version of a service template.</p>', ], 'shapes' => [ 'AcceptEnvironmentAccountConnectionInput' => [ 'base' => NULL, 'refs' => [], ], 'AcceptEnvironmentAccountConnectionOutput' => [ 'base' => NULL, 'refs' => [], ], 'AccessDeniedException' => [ 'base' => '<p>There <i>isn\'t</i> sufficient access for performing this action.</p>', 'refs' => [], ], 'AccountSettings' => [ 'base' => '<p>The AWS Proton pipeline service role data.</p>', 'refs' => [ 'GetAccountSettingsOutput$accountSettings' => '<p>The AWS Proton pipeline service role detail data that\'s returned by AWS Proton.</p>', 'UpdateAccountSettingsOutput$accountSettings' => '<p>The AWS Proton pipeline service role detail data that\'s returned by AWS Proton.</p>', ], ], 'Arn' => [ 'base' => NULL, 'refs' => [ 'AccountSettings$pipelineServiceRoleArn' => '<p>The Amazon Resource Name (ARN) of the AWS Proton pipeline service role.</p>', 'CreateEnvironmentAccountConnectionInput$roleArn' => '<p>The Amazon Resource Name (ARN) of the IAM service role that\'s created in the environment account. AWS Proton uses this role to provision infrastructure resources in the associated environment account.</p>', 'CreateEnvironmentInput$protonServiceRoleArn' => '<p>The Amazon Resource Name (ARN) of the AWS Proton service role that allows AWS Proton to make calls to other services on your behalf. You must include either the <code>environmentAccountConnectionId</code> or <code>protonServiceRoleArn</code> parameter and value.</p>', 'CreateEnvironmentTemplateInput$encryptionKey' => '<p>A customer provided encryption key that AWS Proton uses to encrypt data.</p>', 'CreateServiceInput$repositoryConnectionArn' => '<p>The Amazon Resource Name (ARN) of the repository connection. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/setting-up-for-service.html#setting-up-vcontrol">Set up repository connection</a> in the <i>AWS Proton Administrator Guide</i> and <a href="https://docs.aws.amazon.com/proton/latest/userguide/proton-setup.html#setup-repo-connection">Setting up with AWS Proton</a> in the <i>AWS Proton User Guide</i>. <i>Don\'t</i> include this parameter if your service template <i>doesn\'t</i> include a service pipeline.</p>', 'CreateServiceTemplateInput$encryptionKey' => '<p>A customer provided encryption key that\'s used to encrypt data.</p>', 'Environment$protonServiceRoleArn' => '<p>The Amazon Resource Name (ARN) of the AWS Proton service role that allows AWS Proton to make calls to other services on your behalf.</p>', 'EnvironmentAccountConnection$roleArn' => '<p>The IAM service role that\'s associated with the environment account connection.</p>', 'EnvironmentAccountConnectionSummary$roleArn' => '<p>The IAM service role that\'s associated with the environment account connection.</p>', 'EnvironmentSummary$protonServiceRoleArn' => '<p>The Amazon Resource Name (ARN) of the AWS Proton service role that allows AWS Proton to make calls to other services on your behalf.</p>', 'EnvironmentTemplate$encryptionKey' => '<p>The customer provided encryption key for the environment template.</p>', 'ListTagsForResourceInput$resourceArn' => '<p>The Amazon Resource Name (ARN) of the resource for the listed tags.</p>', 'Service$repositoryConnectionArn' => '<p>The Amazon Resource Name (ARN) of the repository connection. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/setting-up-for-service.html#setting-up-vcontrol">Set up a repository connection</a> in the <i>AWS Proton Administrator Guide</i> and <a href="https://docs.aws.amazon.com/proton/latest/userguide/proton-setup.html#setup-repo-connection">Setting up with AWS Proton</a> in the <i>AWS Proton User Guide</i>.</p>', 'ServicePipeline$arn' => '<p>The Amazon Resource Name (ARN) of the service pipeline.</p>', 'ServiceTemplate$encryptionKey' => '<p>The customer provided service template encryption key that\'s used to encrypt data.</p>', 'TagResourceInput$resourceArn' => '<p>The Amazon Resource Name (ARN) of the resource that the resource tag is applied to.</p>', 'UntagResourceInput$resourceArn' => '<p>The Amazon Resource Name (ARN) of the resource that the tag is to be removed from.</p>', 'UpdateAccountSettingsInput$pipelineServiceRoleArn' => '<p>The Amazon Resource Name (ARN) of the AWS Proton pipeline service role.</p>', 'UpdateEnvironmentAccountConnectionInput$roleArn' => '<p>The Amazon Resource Name (ARN) of the IAM service role that is associated with the environment account connection to update.</p>', 'UpdateEnvironmentInput$protonServiceRoleArn' => '<p>The Amazon Resource Name (ARN) of the AWS Proton service role that allows AWS Proton to make API calls to other services your behalf.</p>', ], ], 'AwsAccountId' => [ 'base' => NULL, 'refs' => [ 'CreateEnvironmentAccountConnectionInput$managementAccountId' => '<p>The ID of the management account that accepts or rejects the environment account connection. You create an manage the AWS Proton environment in this account. If the management account accepts the environment account connection, AWS Proton can use the associated IAM role to provision environment infrastructure resources in the associated environment account.</p>', 'Environment$environmentAccountId' => '<p>The ID of the environment account that the environment infrastructure resources are provisioned in.</p>', 'EnvironmentAccountConnection$environmentAccountId' => '<p>The environment account that\'s connected to the environment account connection.</p>', 'EnvironmentAccountConnection$managementAccountId' => '<p>The ID of the management account that\'s connected to the environment account connection.</p>', 'EnvironmentAccountConnectionSummary$environmentAccountId' => '<p>The ID of the environment account that\'s connected to the environment account connection.</p>', 'EnvironmentAccountConnectionSummary$managementAccountId' => '<p>The ID of the management account that\'s connected to the environment account connection.</p>', 'EnvironmentSummary$environmentAccountId' => '<p>The ID of the environment account that the environment infrastructure resources are provisioned in.</p>', ], ], 'CancelEnvironmentDeploymentInput' => [ 'base' => NULL, 'refs' => [], ], 'CancelEnvironmentDeploymentOutput' => [ 'base' => NULL, 'refs' => [], ], 'CancelServiceInstanceDeploymentInput' => [ 'base' => NULL, 'refs' => [], ], 'CancelServiceInstanceDeploymentOutput' => [ 'base' => NULL, 'refs' => [], ], 'CancelServicePipelineDeploymentInput' => [ 'base' => NULL, 'refs' => [], ], 'CancelServicePipelineDeploymentOutput' => [ 'base' => NULL, 'refs' => [], ], 'ClientToken' => [ 'base' => NULL, 'refs' => [ 'CreateEnvironmentAccountConnectionInput$clientToken' => '<p>When included, if two identicial requests are made with the same client token, AWS Proton returns the environment account connection that the first request created.</p>', 'CreateEnvironmentTemplateVersionInput$clientToken' => '<p>When included, if two identicial requests are made with the same client token, AWS Proton returns the environment template version that the first request created.</p>', 'CreateServiceTemplateVersionInput$clientToken' => '<p>When included, if two identicial requests are made with the same client token, AWS Proton returns the service template version that the first request created.</p>', ], ], 'CompatibleEnvironmentTemplate' => [ 'base' => '<p>Compatible environment template data.</p>', 'refs' => [ 'CompatibleEnvironmentTemplateList$member' => NULL, ], ], 'CompatibleEnvironmentTemplateInput' => [ 'base' => '<p>Compatible environment template data.</p>', 'refs' => [ 'CompatibleEnvironmentTemplateInputList$member' => NULL, ], ], 'CompatibleEnvironmentTemplateInputList' => [ 'base' => NULL, 'refs' => [ 'CreateServiceTemplateVersionInput$compatibleEnvironmentTemplates' => '<p>An array of compatible environment template objects for the new version of a service template.</p>', 'UpdateServiceTemplateVersionInput$compatibleEnvironmentTemplates' => '<p>An array of compatible environment names for a service template major or minor version to update.</p>', ], ], 'CompatibleEnvironmentTemplateList' => [ 'base' => NULL, 'refs' => [ 'ServiceTemplateVersion$compatibleEnvironmentTemplates' => '<p>An array of compatible environment template names for the major version of a service template.</p>', ], ], 'ConflictException' => [ 'base' => '<p>The request <i>couldn\'t</i> be made due to a conflicting operation or resource.</p>', 'refs' => [], ], 'CreateEnvironmentAccountConnectionInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateEnvironmentAccountConnectionOutput' => [ 'base' => NULL, 'refs' => [], ], 'CreateEnvironmentInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateEnvironmentOutput' => [ 'base' => NULL, 'refs' => [], ], 'CreateEnvironmentTemplateInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateEnvironmentTemplateOutput' => [ 'base' => NULL, 'refs' => [], ], 'CreateEnvironmentTemplateVersionInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateEnvironmentTemplateVersionOutput' => [ 'base' => NULL, 'refs' => [], ], 'CreateServiceInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateServiceOutput' => [ 'base' => NULL, 'refs' => [], ], 'CreateServiceTemplateInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateServiceTemplateOutput' => [ 'base' => NULL, 'refs' => [], ], 'CreateServiceTemplateVersionInput' => [ 'base' => NULL, 'refs' => [], ], 'CreateServiceTemplateVersionOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteEnvironmentAccountConnectionInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteEnvironmentAccountConnectionOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteEnvironmentInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteEnvironmentOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteEnvironmentTemplateInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteEnvironmentTemplateOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteEnvironmentTemplateVersionInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteEnvironmentTemplateVersionOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteServiceInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteServiceOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteServiceTemplateInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteServiceTemplateOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteServiceTemplateVersionInput' => [ 'base' => NULL, 'refs' => [], ], 'DeleteServiceTemplateVersionOutput' => [ 'base' => NULL, 'refs' => [], ], 'DeploymentStatus' => [ 'base' => NULL, 'refs' => [ 'Environment$deploymentStatus' => '<p>The environment deployment status.</p>', 'EnvironmentSummary$deploymentStatus' => '<p>The environment deployment status.</p>', 'ServiceInstance$deploymentStatus' => '<p>The service instance deployment status.</p>', 'ServiceInstanceSummary$deploymentStatus' => '<p>The service instance deployment status.</p>', 'ServicePipeline$deploymentStatus' => '<p>The deployment status of the service pipeline.</p>', ], ], 'DeploymentUpdateType' => [ 'base' => NULL, 'refs' => [ 'UpdateEnvironmentInput$deploymentType' => '<p>There are four modes for updating an environment as described in the following. The <code>deploymentType</code> field defines the mode.</p> <dl> <dt/> <dd> <p> <code>NONE</code> </p> <p>In this mode, a deployment <i>doesn\'t</i> occur. Only the requested metadata parameters are updated.</p> </dd> <dt/> <dd> <p> <code>CURRENT_VERSION</code> </p> <p>In this mode, the environment is deployed and updated with the new spec that you provide. Only requested parameters are updated. <i>Don’t</i> include minor or major version parameters when you use this <code>deployment-type</code>.</p> </dd> <dt/> <dd> <p> <code>MINOR_VERSION</code> </p> <p>In this mode, the environment is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.</p> </dd> <dt/> <dd> <p> <code>MAJOR_VERSION</code> </p> <p>In this mode, the environment is deployed and updated with the published, recommended (latest) major and minor version of the current template, by default. You can also specify a different major version that is higher than the major version in use and a minor version (optional).</p> </dd> </dl>', 'UpdateServiceInstanceInput$deploymentType' => '<p>The deployment type.</p> <p>There are four modes for updating a service instance as described in the following. The <code>deploymentType</code> field defines the mode.</p> <dl> <dt/> <dd> <p> <code>NONE</code> </p> <p>In this mode, a deployment <i>doesn\'t</i> occur. Only the requested metadata parameters are updated.</p> </dd> <dt/> <dd> <p> <code>CURRENT_VERSION</code> </p> <p>In this mode, the service instance is deployed and updated with the new spec that you provide. Only requested parameters are updated. <i>Don’t</i> include minor or major version parameters when you use this <code>deployment-type</code>.</p> </dd> <dt/> <dd> <p> <code>MINOR_VERSION</code> </p> <p>In this mode, the service instance is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.</p> </dd> <dt/> <dd> <p> <code>MAJOR_VERSION</code> </p> <p>In this mode, the service instance is deployed and updated with the published, recommended (latest) major and minor version of the current template, by default. You can also specify a different major version that is higher than the major version in use and a minor version (optional).</p> </dd> </dl>', 'UpdateServicePipelineInput$deploymentType' => '<p>The deployment type.</p> <p>There are four modes for updating a service pipeline as described in the following. The <code>deploymentType</code> field defines the mode.</p> <dl> <dt/> <dd> <p> <code>NONE</code> </p> <p>In this mode, a deployment <i>doesn\'t</i> occur. Only the requested metadata parameters are updated.</p> </dd> <dt/> <dd> <p> <code>CURRENT_VERSION</code> </p> <p>In this mode, the service pipeline is deployed and updated with the new spec that you provide. Only requested parameters are updated. <i>Don’t</i> include minor or major version parameters when you use this <code>deployment-type</code>.</p> </dd> <dt/> <dd> <p> <code>MINOR_VERSION</code> </p> <p>In this mode, the service pipeline is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.</p> </dd> <dt/> <dd> <p> <code>MAJOR_VERSION</code> </p> <p>In this mode, the service pipeline is deployed and updated with the published, recommended (latest) major and minor version of the current template, by default. You can also specify a different major version that is higher than the major version in use and a minor version (optional).</p> </dd> </dl>', ], ], 'Description' => [ 'base' => NULL, 'refs' => [ 'CreateEnvironmentInput$description' => '<p>A description of the environment that\'s being created and deployed.</p>', 'CreateEnvironmentTemplateInput$description' => '<p>A description of the environment template.</p>', 'CreateEnvironmentTemplateVersionInput$description' => '<p>A description of the new version of an environment template.</p>', 'CreateServiceInput$description' => '<p>A description of the AWS Proton service.</p>', 'CreateServiceTemplateInput$description' => '<p>A description of the service template.</p>', 'CreateServiceTemplateVersionInput$description' => '<p>A description of the new version of a service template.</p>', 'Environment$description' => '<p>The description of the environment.</p>', 'EnvironmentSummary$description' => '<p>The description of the environment.</p>', 'EnvironmentTemplate$description' => '<p>A description of the environment template.</p>', 'EnvironmentTemplateSummary$description' => '<p>A description of the environment template.</p>', 'EnvironmentTemplateVersion$description' => '<p>A description of the minor version of an environment template.</p>', 'EnvironmentTemplateVersionSummary$description' => '<p>A description of the version of an environment template.</p>', 'Service$description' => '<p>A description of a service.</p>', 'ServiceSummary$description' => '<p>A description of the service.</p>', 'ServiceTemplate$description' => '<p>A description of the service template.</p>', 'ServiceTemplateSummary$description' => '<p>A description of the service template.</p>', 'ServiceTemplateVersion$description' => '<p>A description of the version of a service template.</p>', 'ServiceTemplateVersionSummary$description' => '<p>A description of the version of a service template.</p>', 'UpdateEnvironmentInput$description' => '<p>A description of the environment update.</p>', 'UpdateEnvironmentTemplateInput$description' => '<p>A description of the environment template update.</p>', 'UpdateEnvironmentTemplateVersionInput$description' => '<p>A description of environment template version to update.</p>', 'UpdateServiceInput$description' => '<p>The edited service description.</p>', 'UpdateServiceTemplateInput$description' => '<p>A description of the service template update.</p>', 'UpdateServiceTemplateVersionInput$description' => '<p>A description of a service template version to update.</p>', ], ], 'DisplayName' => [ 'base' => NULL, 'refs' => [ 'CreateEnvironmentTemplateInput$displayName' => '<p>The environment template name as displayed in the developer interface.</p>', 'CreateServiceTemplateInput$displayName' => '<p>The name of the service template as displayed in the developer interface.</p>', 'EnvironmentTemplate$displayName' => '<p>The name of the environment template as displayed in the developer interface.</p>', 'EnvironmentTemplateSummary$displayName' => '<p>The name of the environment template as displayed in the developer interface.</p>', 'ServiceTemplate$displayName' => '<p>The service template name as displayed in the developer interface.</p>', 'ServiceTemplateSummary$displayName' => '<p>The service template name as displayed in the developer interface.</p>', 'UpdateEnvironmentTemplateInput$displayName' => '<p>The name of the environment template to update as displayed in the developer interface.</p>', 'UpdateServiceTemplateInput$displayName' => '<p>The name of the service template to update as displayed in the developer interface.</p>', ], ], 'Environment' => [ 'base' => '<p>The environment detail data. An AWS Proton environment is a set resources shared across an AWS Proton service.</p>', 'refs' => [ 'CancelEnvironmentDeploymentOutput$environment' => '<p>The environment summary data that\'s returned by AWS Proton.</p>', 'CreateEnvironmentOutput$environment' => '<p>The environment detail data that\'s returned by AWS Proton.</p>', 'DeleteEnvironmentOutput$environment' => '<p>The environment detail data that\'s returned by AWS Proton.</p>', 'GetEnvironmentOutput$environment' => '<p>The environment detail data that\'s returned by AWS Proton.</p>', 'UpdateEnvironmentOutput$environment' => '<p>The environment detail data that\'s returned by AWS Proton.</p>', ], ], 'EnvironmentAccountConnection' => [ 'base' => '<p>The environment account connection detail data.</p>', 'refs' => [ 'AcceptEnvironmentAccountConnectionOutput$environmentAccountConnection' => '<p>The environment account connection data that\'s returned by AWS Proton.</p>', 'CreateEnvironmentAccountConnectionOutput$environmentAccountConnection' => '<p>The environment account connection detail data that\'s returned by AWS Proton.</p>', 'DeleteEnvironmentAccountConnectionOutput$environmentAccountConnection' => '<p>The environment account connection detail data that\'s returned by AWS Proton.</p>', 'GetEnvironmentAccountConnectionOutput$environmentAccountConnection' => '<p>The environment account connection detail data that\'s returned by AWS Proton.</p>', 'RejectEnvironmentAccountConnectionOutput$environmentAccountConnection' => '<p>The environment connection account detail data that\'s returned by AWS Proton.</p>', 'UpdateEnvironmentAccountConnectionOutput$environmentAccountConnection' => '<p>The environment account connection detail data that\'s returned by AWS Proton.</p>', ], ], 'EnvironmentAccountConnectionArn' => [ 'base' => NULL, 'refs' => [ 'EnvironmentAccountConnection$arn' => '<p>The Amazon Resource Name (ARN) of the environment account connection.</p>', 'EnvironmentAccountConnectionSummary$arn' => '<p>The Amazon Resource Name (ARN) of the environment account connection.</p>', ], ], 'EnvironmentAccountConnectionId' => [ 'base' => NULL, 'refs' => [ 'AcceptEnvironmentAccountConnectionInput$id' => '<p>The ID of the environment account connection.</p>', 'CreateEnvironmentInput$environmentAccountConnectionId' => '<p>The ID of the environment account connection that you provide if you\'re provisioning your environment infrastructure resources to an environment account. You must include either the <code>environmentAccountConnectionId</code> or <code>protonServiceRoleArn</code> parameter and value. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-env-account-connections.html">Environment account connections</a> in the <i>AWS Proton Administrator guide</i>.</p>', 'DeleteEnvironmentAccountConnectionInput$id' => '<p>The ID of the environment account connection to delete.</p>', 'Environment$environmentAccountConnectionId' => '<p>The ID of the environment account connection that\'s used to provision infrastructure resources in an environment account.</p>', 'EnvironmentAccountConnection$id' => '<p>The ID of the environment account connection.</p>', 'EnvironmentAccountConnectionSummary$id' => '<p>The ID of the environment account connection.</p>', 'EnvironmentSummary$environmentAccountConnectionId' => '<p>The ID of the environment account connection that the environment is associated with.</p>', 'GetEnvironmentAccountConnectionInput$id' => '<p>The ID of the environment account connection.</p>', 'RejectEnvironmentAccountConnectionInput$id' => '<p>The ID of the environment account connection to reject.</p>', 'UpdateEnvironmentAccountConnectionInput$id' => '<p>The ID of the environment account connection to update.</p>', 'UpdateEnvironmentInput$environmentAccountConnectionId' => '<p>The ID of the environment account connection.</p> <p>You can only update to a new environment account connection if it was created in the same environment account that the current environment account connection was created in and is associated with the current environment.</p>', ], ], 'EnvironmentAccountConnectionRequesterAccountType' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentAccountConnectionsInput$requestedBy' => '<p>The type of account making the <code>ListEnvironmentAccountConnections</code> request.</p>', ], ], 'EnvironmentAccountConnectionStatus' => [ 'base' => NULL, 'refs' => [ 'EnvironmentAccountConnection$status' => '<p>The status of the environment account connection.</p>', 'EnvironmentAccountConnectionStatusList$member' => NULL, 'EnvironmentAccountConnectionSummary$status' => '<p>The status of the environment account connection.</p>', ], ], 'EnvironmentAccountConnectionStatusList' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentAccountConnectionsInput$statuses' => '<p>The status details for each listed environment account connection.</p>', ], ], 'EnvironmentAccountConnectionSummary' => [ 'base' => '<p>A summary of the environment account connection detail data.</p>', 'refs' => [ 'EnvironmentAccountConnectionSummaryList$member' => NULL, ], ], 'EnvironmentAccountConnectionSummaryList' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentAccountConnectionsOutput$environmentAccountConnections' => '<p>An array of environment account connections with details that\'s returned by AWS Proton. </p>', ], ], 'EnvironmentArn' => [ 'base' => NULL, 'refs' => [ 'Environment$arn' => '<p>The Amazon Resource Name (ARN) of the environment.</p>', 'EnvironmentSummary$arn' => '<p>The Amazon Resource Name (ARN) of the environment.</p>', ], ], 'EnvironmentSummary' => [ 'base' => '<p>A summary of the environment detail data.</p>', 'refs' => [ 'EnvironmentSummaryList$member' => NULL, ], ], 'EnvironmentSummaryList' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentsOutput$environments' => '<p>An array of environment detail data summaries.</p>', ], ], 'EnvironmentTemplate' => [ 'base' => '<p>The environment template data.</p>', 'refs' => [ 'CreateEnvironmentTemplateOutput$environmentTemplate' => '<p>The environment template detail data that\'s returned by AWS Proton.</p>', 'DeleteEnvironmentTemplateOutput$environmentTemplate' => '<p>The environment template detail data that\'s returned by AWS Proton.</p>', 'GetEnvironmentTemplateOutput$environmentTemplate' => '<p>The environment template detail data that\'s returned by AWS Proton.</p>', 'UpdateEnvironmentTemplateOutput$environmentTemplate' => '<p>The environment template detail data that\'s returned by AWS Proton.</p>', ], ], 'EnvironmentTemplateArn' => [ 'base' => NULL, 'refs' => [ 'EnvironmentTemplate$arn' => '<p>The Amazon Resource Name (ARN) of the environment template.</p>', 'EnvironmentTemplateSummary$arn' => '<p>The Amazon Resource Name (ARN) of the environment template.</p>', ], ], 'EnvironmentTemplateFilter' => [ 'base' => '<p>A search filter for environment templates.</p>', 'refs' => [ 'EnvironmentTemplateFilterList$member' => NULL, ], ], 'EnvironmentTemplateFilterList' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentsInput$environmentTemplates' => '<p>An array of the versions of the environment template.</p>', ], ], 'EnvironmentTemplateSummary' => [ 'base' => '<p>The environment template data.</p>', 'refs' => [ 'EnvironmentTemplateSummaryList$member' => NULL, ], ], 'EnvironmentTemplateSummaryList' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentTemplatesOutput$templates' => '<p>An array of environment templates with detail data.</p>', ], ], 'EnvironmentTemplateVersion' => [ 'base' => '<p>The environment template version data.</p>', 'refs' => [ 'CreateEnvironmentTemplateVersionOutput$environmentTemplateVersion' => '<p>The environment template detail data that\'s returned by AWS Proton.</p>', 'DeleteEnvironmentTemplateVersionOutput$environmentTemplateVersion' => '<p>The environment template version detail data that\'s returned by AWS Proton.</p>', 'GetEnvironmentTemplateVersionOutput$environmentTemplateVersion' => '<p>The environment template version detail data that\'s returned by AWS Proton.</p>', 'UpdateEnvironmentTemplateVersionOutput$environmentTemplateVersion' => '<p>The environment template version detail data that\'s returned by AWS Proton.</p>', ], ], 'EnvironmentTemplateVersionArn' => [ 'base' => NULL, 'refs' => [ 'EnvironmentTemplateVersion$arn' => '<p>The Amazon Resource Name (ARN) of the version of an environment template.</p>', 'EnvironmentTemplateVersionSummary$arn' => '<p>The Amazon Resource Name (ARN) of the version of an environment template.</p>', ], ], 'EnvironmentTemplateVersionSummary' => [ 'base' => '<p>A summary of the version of an environment template detail data.</p>', 'refs' => [ 'EnvironmentTemplateVersionSummaryList$member' => NULL, ], ], 'EnvironmentTemplateVersionSummaryList' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentTemplateVersionsOutput$templateVersions' => '<p>An array of major or minor versions of an environment template detail data.</p>', ], ], 'ErrorMessage' => [ 'base' => NULL, 'refs' => [ 'AccessDeniedException$message' => NULL, 'ConflictException$message' => NULL, 'InternalServerException$message' => NULL, 'ResourceNotFoundException$message' => NULL, 'ServiceQuotaExceededException$message' => NULL, 'ThrottlingException$message' => NULL, 'ValidationException$message' => NULL, ], ], 'FullTemplateVersionNumber' => [ 'base' => NULL, 'refs' => [ 'EnvironmentTemplate$recommendedVersion' => '<p>The ID of the recommended version of the environment template.</p>', 'EnvironmentTemplateSummary$recommendedVersion' => '<p>The ID of the recommended version of the environment template.</p>', 'ServiceTemplate$recommendedVersion' => '<p>The ID of the recommended version of the service template.</p>', 'ServiceTemplateSummary$recommendedVersion' => '<p>The ID of the recommended version of the service template.</p>', ], ], 'GetAccountSettingsInput' => [ 'base' => NULL, 'refs' => [], ], 'GetAccountSettingsOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetEnvironmentAccountConnectionInput' => [ 'base' => NULL, 'refs' => [], ], 'GetEnvironmentAccountConnectionOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetEnvironmentInput' => [ 'base' => NULL, 'refs' => [], ], 'GetEnvironmentOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetEnvironmentTemplateInput' => [ 'base' => NULL, 'refs' => [], ], 'GetEnvironmentTemplateOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetEnvironmentTemplateVersionInput' => [ 'base' => NULL, 'refs' => [], ], 'GetEnvironmentTemplateVersionOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetServiceInput' => [ 'base' => NULL, 'refs' => [], ], 'GetServiceInstanceInput' => [ 'base' => NULL, 'refs' => [], ], 'GetServiceInstanceOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetServiceOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetServiceTemplateInput' => [ 'base' => NULL, 'refs' => [], ], 'GetServiceTemplateOutput' => [ 'base' => NULL, 'refs' => [], ], 'GetServiceTemplateVersionInput' => [ 'base' => NULL, 'refs' => [], ], 'GetServiceTemplateVersionOutput' => [ 'base' => NULL, 'refs' => [], ], 'GitBranchName' => [ 'base' => NULL, 'refs' => [ 'CreateServiceInput$branchName' => '<p>The name of the code repository branch that holds the code that\'s deployed in AWS Proton. <i>Don\'t</i> include this parameter if your service template <i>doesn\'t</i> include a service pipeline.</p>', 'Service$branchName' => '<p>The name of the code repository branch that holds the code that\'s deployed in AWS Proton.</p>', ], ], 'InternalServerException' => [ 'base' => '<p>The request failed to register with the service.</p>', 'refs' => [], ], 'ListEnvironmentAccountConnectionsInput' => [ 'base' => NULL, 'refs' => [], ], 'ListEnvironmentAccountConnectionsOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListEnvironmentTemplateVersionsInput' => [ 'base' => NULL, 'refs' => [], ], 'ListEnvironmentTemplateVersionsOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListEnvironmentTemplatesInput' => [ 'base' => NULL, 'refs' => [], ], 'ListEnvironmentTemplatesOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListEnvironmentsInput' => [ 'base' => NULL, 'refs' => [], ], 'ListEnvironmentsOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListServiceInstancesInput' => [ 'base' => NULL, 'refs' => [], ], 'ListServiceInstancesOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListServiceTemplateVersionsInput' => [ 'base' => NULL, 'refs' => [], ], 'ListServiceTemplateVersionsOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListServiceTemplatesInput' => [ 'base' => NULL, 'refs' => [], ], 'ListServiceTemplatesOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListServicesInput' => [ 'base' => NULL, 'refs' => [], ], 'ListServicesOutput' => [ 'base' => NULL, 'refs' => [], ], 'ListTagsForResourceInput' => [ 'base' => NULL, 'refs' => [], ], 'ListTagsForResourceOutput' => [ 'base' => NULL, 'refs' => [], ], 'MaxPageResults' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentAccountConnectionsInput$maxResults' => '<p>The maximum number of environment account connections to list.</p>', 'ListEnvironmentTemplateVersionsInput$maxResults' => '<p>The maximum number of major or minor versions of an environment template to list.</p>', 'ListEnvironmentTemplatesInput$maxResults' => '<p>The maximum number of environment templates to list.</p>', 'ListEnvironmentsInput$maxResults' => '<p>The maximum number of environments to list.</p>', 'ListServiceInstancesInput$maxResults' => '<p>The maximum number of service instances to list.</p>', 'ListServiceTemplateVersionsInput$maxResults' => '<p>The maximum number of major or minor versions of a service template to list.</p>', 'ListServiceTemplatesInput$maxResults' => '<p>The maximum number of service templates to list.</p>', 'ListServicesInput$maxResults' => '<p>The maximum number of services to list.</p>', 'ListTagsForResourceInput$maxResults' => '<p>The maximum number of tags to list.</p>', ], ], 'NextToken' => [ 'base' => NULL, 'refs' => [ 'ListEnvironmentAccountConnectionsInput$nextToken' => '<p>A token to indicate the location of the next environment account connection in the array of environment account connections, after the list of environment account connections that was previously requested.</p>', 'ListEnvironmentAccountConnectionsOutput$nextToken' => '<p>A token to indicate the location of the next environment account connection in the array of environment account connections, after the current requested list of environment account connections.</p>', 'ListEnvironmentTemplateVersionsInput$nextToken' => '<p>A token to indicate the location of the next major or minor version in the array of major or minor versions of an environment template, after the list of major or minor versions that was previously requested.</p>', 'ListEnvironmentTemplateVersionsOutput$nextToken' => '<p>A token to indicate the location of the next major or minor version in the array of major or minor versions of an environment template, after the list of major or minor versions that was previously requested.</p>', 'ListEnvironmentTemplatesInput$nextToken' => '<p>A token to indicate the location of the next environment template in the array of environment templates, after the list of environment templates that was previously requested.</p>', 'ListEnvironmentTemplatesOutput$nextToken' => '<p>A token to indicate the location of the next environment template in the array of environment templates, after the current requested list of environment templates.</p>', 'ListEnvironmentsInput$nextToken' => '<p>A token to indicate the location of the next environment in the array of environments, after the list of environments that was previously requested.</p>', 'ListEnvironmentsOutput$nextToken' => '<p>A token to indicate the location of the next environment in the array of environments, after the current requested list of environments.</p>', 'ListServiceInstancesInput$nextToken' => '<p>A token to indicate the location of the next service in the array of service instances, after the list of service instances that was previously requested.</p>', 'ListServiceInstancesOutput$nextToken' => '<p>A token to indicate the location of the next service instance in the array of service instances, after the current requested list of service instances.</p>', 'ListServiceTemplateVersionsInput$nextToken' => '<p>A token to indicate the location of the next major or minor version in the array of major or minor versions of a service template, after the list of major or minor versions that was previously requested.</p>', 'ListServiceTemplateVersionsOutput$nextToken' => '<p>A token to indicate the location of the next major or minor version in the array of major or minor versions of a service template, after the list of major or minor versions that was previously requested.</p>', 'ListServiceTemplatesInput$nextToken' => '<p>A token to indicate the location of the next service template in the array of service templates, after the list of service templates previously requested.</p>', 'ListServiceTemplatesOutput$nextToken' => '<p>A token to indicate the location of the next service template in the array of service templates, after the current requested list of service templates.</p>', 'ListServicesInput$nextToken' => '<p>A token to indicate the location of the next service in the array of services, after the list of services that was previously requested.</p>', 'ListServicesOutput$nextToken' => '<p>A token to indicate the location of the next service in the array of services, after the current requested list of services.</p>', ], ], 'Provisioning' => [ 'base' => NULL, 'refs' => [ 'CreateEnvironmentTemplateInput$provisioning' => '<p>When included, indicates that the environment template is for customer provisioned and managed infrastructure.</p>', 'CreateServiceTemplateInput$pipelineProvisioning' => '<p>AWS Proton includes a service pipeline for your service by default. When included, this parameter indicates that an AWS Proton service pipeline <i>won\'t</i> be included for your service. Once specified, this parameter <i>can\'t</i> be changed. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-template-bundles.html">Service template bundles</a> in the <i>AWS Proton Administrator Guide</i>.</p>', 'Environment$provisioning' => '<p>When included, indicates that the environment template is for customer provisioned and managed infrastructure.</p>', 'EnvironmentSummary$provisioning' => '<p>When included, indicates that the environment template is for customer provisioned and managed infrastructure.</p>', 'EnvironmentTemplate$provisioning' => '<p>When included, indicates that the environment template is for customer provisioned and managed infrastructure.</p>', 'EnvironmentTemplateSummary$provisioning' => '<p>When included, indicates that the environment template is for customer provisioned and managed infrastructure.</p>', 'ServiceTemplate$pipelineProvisioning' => '<p>If <code>pipelineProvisioning</code> is <code>true</code>, a service pipeline is included in the service template. Otherwise, a service pipeline <i>isn\'t</i> included in the service template.</p>', 'ServiceTemplateSummary$pipelineProvisioning' => '<p>If <code>pipelineProvisioning</code> is <code>true</code>, a service pipeline is included in the service template, otherwise a service pipeline <i>isn\'t</i> included in the service template.</p>', ], ], 'RejectEnvironmentAccountConnectionInput' => [ 'base' => NULL, 'refs' => [], ], 'RejectEnvironmentAccountConnectionOutput' => [ 'base' => NULL, 'refs' => [], ], 'RepositoryId' => [ 'base' => NULL, 'refs' => [ 'CreateServiceInput$repositoryId' => '<p>The ID of the code repository. <i>Don\'t</i> include this parameter if your service template <i>doesn\'t</i> include a service pipeline.</p>', 'Service$repositoryId' => '<p>The ID of the code repository.</p>', ], ], 'ResourceName' => [ 'base' => NULL, 'refs' => [ 'CancelEnvironmentDeploymentInput$environmentName' => '<p>The name of the environment with the deployment to cancel.</p>', 'CancelServiceInstanceDeploymentInput$serviceInstanceName' => '<p>The name of the service instance with the deployment to cancel.</p>', 'CancelServiceInstanceDeploymentInput$serviceName' => '<p>The name of the service with the service instance deployment to cancel.</p>', 'CancelServicePipelineDeploymentInput$serviceName' => '<p>The name of the service with the service pipeline deployment to cancel.</p>', 'CompatibleEnvironmentTemplate$templateName' => '<p>The compatible environment template name.</p>', 'CompatibleEnvironmentTemplateInput$templateName' => '<p>The compatible environment template name.</p>', 'CreateEnvironmentAccountConnectionInput$environmentName' => '<p>The name of the AWS Proton environment that\'s created in the associated management account.</p>', 'CreateEnvironmentInput$name' => '<p>The name of the environment.</p>', 'CreateEnvironmentInput$templateName' => '<p>The name of the environment template. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-templates.html">Environment Templates</a> in the <i>AWS Proton Administrator Guide</i>.</p>', 'CreateEnvironmentTemplateInput$name' => '<p>The name of the environment template.</p>', 'CreateEnvironmentTemplateVersionInput$templateName' => '<p>The name of the environment template.</p>', 'CreateServiceInput$name' => '<p>The service name.</p>', 'CreateServiceInput$templateName' => '<p>The name of the service template that\'s used to create the service.</p>', 'CreateServiceTemplateInput$name' => '<p>The name of the service template.</p>', 'CreateServiceTemplateVersionInput$templateName' => '<p>The name of the service template.</p>', 'DeleteEnvironmentInput$name' => '<p>The name of the environment to delete.</p>', 'DeleteEnvironmentTemplateInput$name' => '<p>The name of the environment template to delete.</p>', 'DeleteEnvironmentTemplateVersionInput$templateName' => '<p>The name of the environment template.</p>', 'DeleteServiceInput$name' => '<p>The name of the service to delete.</p>', 'DeleteServiceTemplateInput$name' => '<p>The name of the service template to delete.</p>', 'DeleteServiceTemplateVersionInput$templateName' => '<p>The name of the service template.</p>', 'Environment$name' => '<p>The name of the environment.</p>', 'Environment$templateName' => '<p>The Amazon Resource Name (ARN) of the environment template.</p>', 'EnvironmentAccountConnection$environmentName' => '<p>The name of the environment that\'s associated with the environment account connection.</p>', 'EnvironmentAccountConnectionSummary$environmentName' => '<p>The name of the environment that\'s associated with the environment account connection.</p>', 'EnvironmentSummary$name' => '<p>The name of the environment.</p>', 'EnvironmentSummary$templateName' => '<p>The name of the environment template.</p>', 'EnvironmentTemplate$name' => '<p>The name of the environment template.</p>', 'EnvironmentTemplateFilter$templateName' => '<p>Include <code>templateName</code> to filter search for a template name.</p>', 'EnvironmentTemplateSummary$name' => '<p>The name of the environment template.</p>', 'EnvironmentTemplateVersion$templateName' => '<p>The name of the version of an environment template.</p>', 'EnvironmentTemplateVersionSummary$templateName' => '<p>The name of the version of an environment template.</p>', 'GetEnvironmentInput$name' => '<p>The name of the environment that you want to get the detail data for.</p>', 'GetEnvironmentTemplateInput$name' => '<p>The name of the environment template that you want to get the detail data for.</p>', 'GetEnvironmentTemplateVersionInput$templateName' => '<p>The name of the environment template.</p>', 'GetServiceInput$name' => '<p>The name of the service that you want to get the detail data for.</p>', 'GetServiceInstanceInput$name' => '<p>The name of a service instance that you want to get the detail data for.</p>', 'GetServiceInstanceInput$serviceName' => '<p>The name of the service that the service instance belongs to.</p>', 'GetServiceTemplateInput$name' => '<p>The name of the service template that you want to get detail data for.</p>', 'GetServiceTemplateVersionInput$templateName' => '<p>The name of the service template.</p>', 'ListEnvironmentAccountConnectionsInput$environmentName' => '<p>The environment name that\'s associated with each listed environment account connection.</p>', 'ListEnvironmentTemplateVersionsInput$templateName' => '<p>The name of the environment template.</p>', 'ListServiceInstancesInput$serviceName' => '<p>The name of the service that the service instance belongs to.</p>', 'ListServiceTemplateVersionsInput$templateName' => '<p>The name of the service template.</p>', 'Service$name' => '<p>The name of the service.</p>', 'Service$templateName' => '<p>The name of the service template.</p>', 'ServiceInstance$environmentName' => '<p>The name of the environment that the service instance was deployed into.</p>', 'ServiceInstance$name' => '<p>The name of the service instance.</p>', 'ServiceInstance$serviceName' => '<p>The name of the service that the service instance belongs to.</p>', 'ServiceInstance$templateName' => '<p>The name of the service template that was used to create the service instance.</p>', 'ServiceInstanceSummary$environmentName' => '<p>The name of the environment that the service instance was deployed into.</p>', 'ServiceInstanceSummary$name' => '<p>The name of the service instance.</p>', 'ServiceInstanceSummary$serviceName' => '<p>The name of the service that the service instance belongs to.</p>', 'ServiceInstanceSummary$templateName' => '<p>The name of the service template.</p>', 'ServicePipeline$templateName' => '<p>The name of the service template that was used to create the service pipeline.</p>', 'ServiceSummary$name' => '<p>The name of the service.</p>', 'ServiceSummary$templateName' => '<p>The name of the service template.</p>', 'ServiceTemplate$name' => '<p>The name of the service template.</p>', 'ServiceTemplateSummary$name' => '<p>The name of the service template.</p>', 'ServiceTemplateVersion$templateName' => '<p>The name of the version of a service template.</p>', 'ServiceTemplateVersionSummary$templateName' => '<p>The name of the service template.</p>', 'UpdateEnvironmentInput$name' => '<p>The name of the environment to update.</p>', 'UpdateEnvironmentTemplateInput$name' => '<p>The name of the environment template to update.</p>', 'UpdateEnvironmentTemplateVersionInput$templateName' => '<p>The name of the environment template.</p>', 'UpdateServiceInput$name' => '<p>The name of the service to edit.</p>', 'UpdateServiceInstanceInput$name' => '<p>The name of the service instance to update.</p>', 'UpdateServiceInstanceInput$serviceName' => '<p>The name of the service that the service instance belongs to.</p>', 'UpdateServicePipelineInput$serviceName' => '<p>The name of the service to that the pipeline is associated with.</p>', 'UpdateServiceTemplateInput$name' => '<p>The name of the service template to update.</p>', 'UpdateServiceTemplateVersionInput$templateName' => '<p>The name of the service template.</p>', ], ], 'ResourceNotFoundException' => [ 'base' => '<p>The requested resource <i>wasn\'t</i> found.</p>', 'refs' => [], ], 'S3Bucket' => [ 'base' => NULL, 'refs' => [ 'S3ObjectSource$bucket' => '<p>The name of the S3 bucket that contains a template bundle.</p>', ], ], 'S3Key' => [ 'base' => NULL, 'refs' => [ 'S3ObjectSource$key' => '<p>The path to the S3 bucket that contains a template bundle.</p>', ], ], 'S3ObjectSource' => [ 'base' => '<p>Template bundle S3 bucket data.</p>', 'refs' => [ 'TemplateVersionSourceInput$s3' => '<p>An S3 source object that includes the template bundle S3 path and name for a template minor version.</p>', ], ], 'Service' => [ 'base' => '<p>The service detail data.</p>', 'refs' => [ 'CreateServiceOutput$service' => '<p>The service detail data that\'s returned by AWS Proton.</p>', 'DeleteServiceOutput$service' => '<p>The service detail data that\'s returned by AWS Proton.</p>', 'GetServiceOutput$service' => '<p>The service detail data that\'s returned by AWS Proton.</p>', 'UpdateServiceOutput$service' => '<p>The service detail data that\'s returned by AWS Proton.</p>', ], ], 'ServiceArn' => [ 'base' => NULL, 'refs' => [ 'Service$arn' => '<p>The Amazon Resource Name (ARN) of the service.</p>', 'ServiceSummary$arn' => '<p>The Amazon Resource Name (ARN) of the service.</p>', ], ], 'ServiceInstance' => [ 'base' => '<p>The service instance detail data.</p>', 'refs' => [ 'CancelServiceInstanceDeploymentOutput$serviceInstance' => '<p>The service instance summary data that\'s returned by AWS Proton.</p>', 'GetServiceInstanceOutput$serviceInstance' => '<p>The service instance detail data that\'s returned by AWS Proton.</p>', 'UpdateServiceInstanceOutput$serviceInstance' => '<p>The service instance summary data returned by AWS Proton.</p>', ], ], 'ServiceInstanceArn' => [ 'base' => NULL, 'refs' => [ 'ServiceInstance$arn' => '<p>The Amazon Resource Name (ARN) of the service instance.</p>', 'ServiceInstanceSummary$arn' => '<p>The Amazon Resource Name (ARN) of the service instance.</p>', ], ], 'ServiceInstanceSummary' => [ 'base' => '<p>A summary of the service instance detail data.</p>', 'refs' => [ 'ServiceInstanceSummaryList$member' => NULL, ], ], 'ServiceInstanceSummaryList' => [ 'base' => NULL, 'refs' => [ 'ListServiceInstancesOutput$serviceInstances' => '<p>An array of service instances with summaries of detail data.</p>', ], ], 'ServicePipeline' => [ 'base' => '<p>The service pipeline detail data.</p>', 'refs' => [ 'CancelServicePipelineDeploymentOutput$pipeline' => '<p>The service pipeline detail data that\'s returned by AWS Proton.</p>', 'Service$pipeline' => '<p>The service pipeline detail data.</p>', 'UpdateServicePipelineOutput$pipeline' => '<p>The pipeline details returned by AWS Proton.</p>', ], ], 'ServiceQuotaExceededException' => [ 'base' => '<p>A quota was exceeded. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-limits.html">AWS Proton Quotas</a> in the <i>AWS Proton Administrator Guide</i>.</p>', 'refs' => [], ], 'ServiceStatus' => [ 'base' => NULL, 'refs' => [ 'Service$status' => '<p>The status of the service.</p>', 'ServiceSummary$status' => '<p>The status of the service.</p>', ], ], 'ServiceSummary' => [ 'base' => '<p>A summary of the service detail data.</p>', 'refs' => [ 'ServiceSummaryList$member' => NULL, ], ], 'ServiceSummaryList' => [ 'base' => NULL, 'refs' => [ 'ListServicesOutput$services' => '<p>An array of services with summaries of detail data.</p>', ], ], 'ServiceTemplate' => [ 'base' => '<p>The service template detail data.</p>', 'refs' => [ 'CreateServiceTemplateOutput$serviceTemplate' => '<p>The service template detail data that\'s returned by AWS Proton.</p>', 'DeleteServiceTemplateOutput$serviceTemplate' => '<p>The service template detail data that\'s returned by AWS Proton.</p>', 'GetServiceTemplateOutput$serviceTemplate' => '<p>The service template detail data that\'s returned by AWS Proton.</p>', 'UpdateServiceTemplateOutput$serviceTemplate' => '<p>The service template detail data that\'s returned by AWS Proton.</p>', ], ], 'ServiceTemplateArn' => [ 'base' => NULL, 'refs' => [ 'ServiceTemplate$arn' => '<p>The Amazon Resource Name (ARN) of the service template.</p>', 'ServiceTemplateSummary$arn' => '<p>The Amazon Resource Name (ARN) of the service template.</p>', ], ], 'ServiceTemplateSummary' => [ 'base' => '<p>The service template summary data.</p>', 'refs' => [ 'ServiceTemplateSummaryList$member' => NULL, ], ], 'ServiceTemplateSummaryList' => [ 'base' => NULL, 'refs' => [ 'ListServiceTemplatesOutput$templates' => '<p>An array of service templates with detail data.</p>', ], ], 'ServiceTemplateVersion' => [ 'base' => '<p>The version of a service template detail data.</p>', 'refs' => [ 'CreateServiceTemplateVersionOutput$serviceTemplateVersion' => '<p>The service template version summary of detail data that\'s returned by AWS Proton.</p>', 'DeleteServiceTemplateVersionOutput$serviceTemplateVersion' => '<p>The service template version detail data that\'s returned by AWS Proton.</p>', 'GetServiceTemplateVersionOutput$serviceTemplateVersion' => '<p>The service template version detail data that\'s returned by AWS Proton.</p>', 'UpdateServiceTemplateVersionOutput$serviceTemplateVersion' => '<p>The service template version detail data that\'s returned by AWS Proton.</p>', ], ], 'ServiceTemplateVersionArn' => [ 'base' => NULL, 'refs' => [ 'ServiceTemplateVersion$arn' => '<p>The Amazon Resource Name (ARN) of the version of a service template.</p>', 'ServiceTemplateVersionSummary$arn' => '<p>The Amazon Resource Name (ARN) of the version of a service template.</p>', ], ], 'ServiceTemplateVersionSummary' => [ 'base' => '<p>A summary of the service template version detail data.</p>', 'refs' => [ 'ServiceTemplateVersionSummaryList$member' => NULL, ], ], 'ServiceTemplateVersionSummaryList' => [ 'base' => NULL, 'refs' => [ 'ListServiceTemplateVersionsOutput$templateVersions' => '<p>An array of major or minor versions of a service template with detail data.</p>', ], ], 'SpecContents' => [ 'base' => NULL, 'refs' => [ 'CreateEnvironmentInput$spec' => '<p>A link to a YAML formatted spec file that provides inputs as defined in the environment template bundle schema file. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-environments.html">Environments</a> in the <i>AWS Proton Administrator Guide</i>.</p>', 'CreateServiceInput$spec' => '<p>A link to a spec file that provides inputs as defined in the service template bundle schema file. The spec file is in YAML format. Don’t include pipeline inputs in the spec if your service template <i>doesn’t</i> include a service pipeline. For more information, see <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-create-svc.html.html">Create a service</a> in the <i>AWS Proton Administrator Guide</i> and <a href="https://docs.aws.amazon.com/proton/latest/userguide/ug-svc-create.html">Create a service</a> in the <i>AWS Proton User Guide</i>.</p>', 'Environment$spec' => '<p>The environment spec.</p>', 'Service$spec' => '<p>The formatted specification that defines the service.</p>', 'ServiceInstance$spec' => '<p>The service spec that was used to create the service instance.</p>', 'ServicePipeline$spec' => '<p>The service spec that was used to create the service pipeline.</p>', 'UpdateEnvironmentInput$spec' => '<p>The formatted specification that defines the update.</p>', 'UpdateServiceInput$spec' => '<p>Lists the service instances to add and the existing service instances to remain. Omit the existing service instances to delete from the list. <i>Don\'t</i> include edits to the existing service instances or pipeline. For more information, see <i>Edit a service</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/ag-svc-update.html">AWS Proton Administrator Guide</a> or the <a href="https://docs.aws.amazon.com/proton/latest/userguide/ug-svc-update.html">AWS Proton User Guide</a>.</p>', 'UpdateServiceInstanceInput$spec' => '<p>The formatted specification that defines the service instance update.</p>', 'UpdateServicePipelineInput$spec' => '<p>The spec for the service pipeline to update.</p>', ], ], 'StatusMessage' => [ 'base' => NULL, 'refs' => [ 'Environment$deploymentStatusMessage' => '<p>An environment deployment status message.</p>', 'EnvironmentSummary$deploymentStatusMessage' => '<p>An environment deployment status message.</p>', 'EnvironmentTemplateVersion$statusMessage' => '<p>The status message of the version of an environment template.</p>', 'EnvironmentTemplateVersionSummary$statusMessage' => '<p>The status message of the version of an environment template.</p>', 'Service$statusMessage' => '<p>A service status message.</p>', 'ServiceInstance$deploymentStatusMessage' => '<p>A service instance deployment status message.</p>', 'ServiceInstanceSummary$deploymentStatusMessage' => '<p>A service instance deployment status message.</p>', 'ServicePipeline$deploymentStatusMessage' => '<p>A service pipeline deployment status message.</p>', 'ServiceSummary$statusMessage' => '<p>A service status message.</p>', 'ServiceTemplateVersion$statusMessage' => '<p>A service template version status message.</p>', 'ServiceTemplateVersionSummary$statusMessage' => '<p>A service template minor version status message.</p>', ], ], 'String' => [ 'base' => NULL, 'refs' => [ 'ListTagsForResourceInput$nextToken' => '<p>A token to indicate the location of the next resource tag in the array of resource tags, after the list of resource tags that was previously requested.</p>', 'ListTagsForResourceOutput$nextToken' => '<p>A token to indicate the location of the next resource tag in the array of resource tags, after the current requested list of resource tags.</p>', ], ], 'Tag' => [ 'base' => '<p>A description of a resource tag.</p>', 'refs' => [ 'TagList$member' => NULL, ], ], 'TagKey' => [ 'base' => NULL, 'refs' => [ 'Tag$key' => '<p>The key of the resource tag.</p>', 'TagKeyList$member' => NULL, ], ], 'TagKeyList' => [ 'base' => NULL, 'refs' => [ 'UntagResourceInput$tagKeys' => '<p>An array of tag keys indicating the resource tags to be removed from the resource.</p>', ], ], 'TagList' => [ 'base' => NULL, 'refs' => [ 'CreateEnvironmentInput$tags' => '<p>Create tags for your environment. For more information, see <i>AWS Proton resources and tagging</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/resources.html">AWS Proton Administrator Guide</a> or <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">AWS Proton User Guide</a>.</p>', 'CreateEnvironmentTemplateInput$tags' => '<p>Create tags for your environment template. For more information, see <i>AWS Proton resources and tagging</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/resources.html">AWS Proton Administrator Guide</a> or <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">AWS Proton User Guide</a>.</p>', 'CreateEnvironmentTemplateVersionInput$tags' => '<p>Create tags for a new version of an environment template.</p>', 'CreateServiceInput$tags' => '<p>Create tags for your service. For more information, see <i>AWS Proton resources and tagging</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/resources.html">AWS Proton Administrator Guide</a> or <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">AWS Proton User Guide</a>.</p>', 'CreateServiceTemplateInput$tags' => '<p>Create tags for your service template. For more information, see <i>AWS Proton resources and tagging</i> in the <a href="https://docs.aws.amazon.com/proton/latest/adminguide/resources.html">AWS Proton Administrator Guide</a> or <a href="https://docs.aws.amazon.com/proton/latest/userguide/resources.html">AWS Proton User Guide</a>.</p>', 'CreateServiceTemplateVersionInput$tags' => '<p>Create tags for a new version of a service template.</p>', 'ListTagsForResourceOutput$tags' => '<p>An array of resource tags with detail data.</p>', 'TagResourceInput$tags' => '<p>An array of resource tags to apply to a resource.</p>', ], ], 'TagResourceInput' => [ 'base' => NULL, 'refs' => [], ], 'TagResourceOutput' => [ 'base' => NULL, 'refs' => [], ], 'TagValue' => [ 'base' => NULL, 'refs' => [ 'Tag$value' => '<p>The value of the resource tag.</p>', ], ], 'TemplateSchema' => [ 'base' => NULL, 'refs' => [ 'EnvironmentTemplateVersion$schema' => '<p>The schema of the version of an environment template.</p>', 'ServiceTemplateVersion$schema' => '<p>The schema of the version of a service template.</p>', ], ], 'TemplateVersionPart' => [ 'base' => NULL, 'refs' => [ 'CompatibleEnvironmentTemplate$majorVersion' => '<p>The major version of the compatible environment template.</p>', 'CompatibleEnvironmentTemplateInput$majorVersion' => '<p>The major version of the compatible environment template.</p>', 'CreateEnvironmentInput$templateMajorVersion' => '<p>The ID of the major version of the environment template.</p>', 'CreateEnvironmentInput$templateMinorVersion' => '<p>The ID of the minor version of the environment template.</p>', 'CreateEnvironmentTemplateVersionInput$majorVersion' => '<p>To create a new minor version of the environment template, include a <code>majorVersion</code>.</p> <p>To create a new major and minor version of the environment template, <i>exclude</i> <code>majorVersion</code>.</p>', 'CreateServiceInput$templateMajorVersion' => '<p>The ID of the major version of the service template that was used to create the service.</p>', 'CreateServiceInput$templateMinorVersion' => '<p>The ID of the minor version of the service template that was used to create the service.</p>', 'CreateServiceTemplateVersionInput$majorVersion' => '<p>To create a new minor version of the service template, include a <code>majorVersion</code>.</p> <p>To create a new major and minor version of the service template, <i>exclude</i> <code>majorVersion</code>.</p>', 'DeleteEnvironmentTemplateVersionInput$majorVersion' => '<p>The environment template major version to delete.</p>', 'DeleteEnvironmentTemplateVersionInput$minorVersion' => '<p>The environment template minor version to delete.</p>', 'DeleteServiceTemplateVersionInput$majorVersion' => '<p>The service template major version to delete.</p>', 'DeleteServiceTemplateVersionInput$minorVersion' => '<p>The service template minor version to delete.</p>', 'Environment$templateMajorVersion' => '<p>The ID of the major version of the environment template.</p>', 'Environment$templateMinorVersion' => '<p>The ID of the minor version of the environment template.</p>', 'EnvironmentSummary$templateMajorVersion' => '<p>The ID of the major version of the environment template.</p>', 'EnvironmentSummary$templateMinorVersion' => '<p>The ID of the minor version of the environment template.</p>', 'EnvironmentTemplateFilter$majorVersion' => '<p>Include <code>majorVersion</code> to filter search for a major version.</p>', 'EnvironmentTemplateVersion$majorVersion' => '<p>The ID of the latest major version that\'s associated with the version of an environment template.</p>', 'EnvironmentTemplateVersion$minorVersion' => '<p>The ID of the minor version of an environment template.</p>', 'EnvironmentTemplateVersion$recommendedMinorVersion' => '<p>The ID of the recommended minor version of the environment template.</p>', 'EnvironmentTemplateVersionSummary$majorVersion' => '<p>The ID of the latest major version that\'s associated with the version of an environment template.</p>', 'EnvironmentTemplateVersionSummary$minorVersion' => '<p>The ID of the version of an environment template.</p>', 'EnvironmentTemplateVersionSummary$recommendedMinorVersion' => '<p>The ID of the recommended minor version of the environment template.</p>', 'GetEnvironmentTemplateVersionInput$majorVersion' => '<p>To view environment template major version detail data, include <code>majorVersion</code>.</p>', 'GetEnvironmentTemplateVersionInput$minorVersion' => '<p>To view environment template minor version detail data, include <code>minorVersion</code>.</p>', 'GetServiceTemplateVersionInput$majorVersion' => '<p>To view service template major version detail data, include <code>majorVersion</code>.</p>', 'GetServiceTemplateVersionInput$minorVersion' => '<p>To view service template minor version detail data, include <code>minorVersion</code>.</p>', 'ListEnvironmentTemplateVersionsInput$majorVersion' => '<p>To view a list of minor of versions under a major version of an environment template, include <code>majorVersion</code>.</p> <p>To view a list of major versions of an environment template, <i>exclude</i> <code>majorVersion</code>.</p>', 'ListServiceTemplateVersionsInput$majorVersion' => '<p>To view a list of minor of versions under a major version of a service template, include <code>majorVersion</code>.</p> <p>To view a list of major versions of a service template, <i>exclude</i> <code>majorVersion</code>.</p>', 'ServiceInstance$templateMajorVersion' => '<p>The ID of the major version of the service template that was used to create the service instance.</p>', 'ServiceInstance$templateMinorVersion' => '<p>The ID of the minor version of the service template that was used to create the service instance.</p>', 'ServiceInstanceSummary$templateMajorVersion' => '<p>The ID of the major version of a service template.</p>', 'ServiceInstanceSummary$templateMinorVersion' => '<p>The ID of the minor version of a service template.</p>', 'ServicePipeline$templateMajorVersion' => '<p>The ID of the major version of the service template that was used to create the service pipeline.</p>', 'ServicePipeline$templateMinorVersion' => '<p>The ID of the minor version of the service template that was used to create the service pipeline.</p>', 'ServiceTemplateVersion$majorVersion' => '<p>The ID of the latest major version that\'s associated with the version of a service template.</p>', 'ServiceTemplateVersion$minorVersion' => '<p>The ID of the minor version of a service template.</p>', 'ServiceTemplateVersion$recommendedMinorVersion' => '<p>The ID of the recommended minor version of the service template.</p>', 'ServiceTemplateVersionSummary$majorVersion' => '<p>The ID of the latest major version that\'s associated with the version of a service template.</p>', 'ServiceTemplateVersionSummary$minorVersion' => '<p>The ID of the minor version of a service template.</p>', 'ServiceTemplateVersionSummary$recommendedMinorVersion' => '<p>The ID of the recommended minor version of the service template.</p>', 'UpdateEnvironmentInput$templateMajorVersion' => '<p>The ID of the major version of the environment to update.</p>', 'UpdateEnvironmentInput$templateMinorVersion' => '<p>The ID of the minor version of the environment to update.</p>', 'UpdateEnvironmentTemplateVersionInput$majorVersion' => '<p>To update a major version of an environment template, include <code>majorVersion</code>.</p>', 'UpdateEnvironmentTemplateVersionInput$minorVersion' => '<p>To update a minor version of an environment template, include <code>minorVersion</code>.</p>', 'UpdateServiceInstanceInput$templateMajorVersion' => '<p>The major version of the service template to update.</p>', 'UpdateServiceInstanceInput$templateMinorVersion' => '<p>The minor version of the service template to update.</p>', 'UpdateServicePipelineInput$templateMajorVersion' => '<p>The major version of the service template that was used to create the service that the pipeline is associated with.</p>', 'UpdateServicePipelineInput$templateMinorVersion' => '<p>The minor version of the service template that was used to create the service that the pipeline is associated with.</p>', 'UpdateServiceTemplateVersionInput$majorVersion' => '<p>To update a major version of a service template, include <code>majorVersion</code>.</p>', 'UpdateServiceTemplateVersionInput$minorVersion' => '<p>To update a minor version of a service template, include <code>minorVersion</code>.</p>', ], ], 'TemplateVersionSourceInput' => [ 'base' => '<p>Template version source data.</p>', 'refs' => [ 'CreateEnvironmentTemplateVersionInput$source' => '<p>An object that includes the template bundle S3 bucket path and name for the new version of an template.</p>', 'CreateServiceTemplateVersionInput$source' => '<p>An object that includes the template bundle S3 bucket path and name for the new version of a service template.</p>', ], ], 'TemplateVersionStatus' => [ 'base' => NULL, 'refs' => [ 'EnvironmentTemplateVersion$status' => '<p>The status of the version of an environment template.</p>', 'EnvironmentTemplateVersionSummary$status' => '<p>The status of the version of an environment template.</p>', 'ServiceTemplateVersion$status' => '<p>The service template version status.</p>', 'ServiceTemplateVersionSummary$status' => '<p>The service template minor version status.</p>', 'UpdateEnvironmentTemplateVersionInput$status' => '<p>The status of the environment template minor version to update.</p>', 'UpdateServiceTemplateVersionInput$status' => '<p>The status of the service template minor version to update.</p>', ], ], 'ThrottlingException' => [ 'base' => '<p>The request was denied due to request throttling.</p>', 'refs' => [], ], 'Timestamp' => [ 'base' => NULL, 'refs' => [ 'Environment$createdAt' => '<p>The time when the environment was created.</p>', 'Environment$lastDeploymentAttemptedAt' => '<p>The time when a deployment of the environment was last attempted.</p>', 'Environment$lastDeploymentSucceededAt' => '<p>The time when the environment was last deployed successfully.</p>', 'EnvironmentAccountConnection$lastModifiedAt' => '<p>The time when the environment account connection was last modified.</p>', 'EnvironmentAccountConnection$requestedAt' => '<p>The time when the environment account connection request was made.</p>', 'EnvironmentAccountConnectionSummary$lastModifiedAt' => '<p>The time when the environment account connection was last modified.</p>', 'EnvironmentAccountConnectionSummary$requestedAt' => '<p>The time when the environment account connection request was made.</p>', 'EnvironmentSummary$createdAt' => '<p>The time when the environment was created.</p>', 'EnvironmentSummary$lastDeploymentAttemptedAt' => '<p>The time when a deployment of the environment was last attempted.</p>', 'EnvironmentSummary$lastDeploymentSucceededAt' => '<p>The time when the environment was last deployed successfully.</p>', 'EnvironmentTemplate$createdAt' => '<p>The time when the environment template was created.</p>', 'EnvironmentTemplate$lastModifiedAt' => '<p>The time when the environment template was last modified.</p>', 'EnvironmentTemplateSummary$createdAt' => '<p>The time when the environment template was created.</p>', 'EnvironmentTemplateSummary$lastModifiedAt' => '<p>The time when the environment template was last modified.</p>', 'EnvironmentTemplateVersion$createdAt' => '<p>The time when the version of an environment template was created.</p>', 'EnvironmentTemplateVersion$lastModifiedAt' => '<p>The time when the version of an environment template was last modified.</p>', 'EnvironmentTemplateVersionSummary$createdAt' => '<p>The time when the version of an environment template was created.</p>', 'EnvironmentTemplateVersionSummary$lastModifiedAt' => '<p>The time when the version of an environment template was last modified.</p>', 'Service$createdAt' => '<p>The time when the service was created.</p>', 'Service$lastModifiedAt' => '<p>The time when the service was last modified.</p>', 'ServiceInstance$createdAt' => '<p>The time when the service instance was created.</p>', 'ServiceInstance$lastDeploymentAttemptedAt' => '<p>The time when a deployment of the service instance was last attempted.</p>', 'ServiceInstance$lastDeploymentSucceededAt' => '<p>The time when the service instance was last deployed successfully.</p>', 'ServiceInstanceSummary$createdAt' => '<p>The time when the service instance was created.</p>', 'ServiceInstanceSummary$lastDeploymentAttemptedAt' => '<p>The time when a deployment of the service was last attempted.</p>', 'ServiceInstanceSummary$lastDeploymentSucceededAt' => '<p>The time when the service was last deployed successfully.</p>', 'ServicePipeline$createdAt' => '<p>The time when the service pipeline was created.</p>', 'ServicePipeline$lastDeploymentAttemptedAt' => '<p>The time when a deployment of the service pipeline was last attempted.</p>', 'ServicePipeline$lastDeploymentSucceededAt' => '<p>The time when the service pipeline was last deployed successfully.</p>', 'ServiceSummary$createdAt' => '<p>The time when the service was created.</p>', 'ServiceSummary$lastModifiedAt' => '<p>The time when the service was last modified.</p>', 'ServiceTemplate$createdAt' => '<p>The time when the service template was created.</p>', 'ServiceTemplate$lastModifiedAt' => '<p>The time when the service template was last modified.</p>', 'ServiceTemplateSummary$createdAt' => '<p>The time when the service template was created.</p>', 'ServiceTemplateSummary$lastModifiedAt' => '<p>The time when the service template was last modified.</p>', 'ServiceTemplateVersion$createdAt' => '<p>The time when the version of a service template was created.</p>', 'ServiceTemplateVersion$lastModifiedAt' => '<p>The time when the version of a service template was last modified.</p>', 'ServiceTemplateVersionSummary$createdAt' => '<p>The time when the version of a service template was created.</p>', 'ServiceTemplateVersionSummary$lastModifiedAt' => '<p>The time when the version of a service template was last modified.</p>', ], ], 'UntagResourceInput' => [ 'base' => NULL, 'refs' => [], ], 'UntagResourceOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateAccountSettingsInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateAccountSettingsOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateEnvironmentAccountConnectionInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateEnvironmentAccountConnectionOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateEnvironmentInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateEnvironmentOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateEnvironmentTemplateInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateEnvironmentTemplateOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateEnvironmentTemplateVersionInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateEnvironmentTemplateVersionOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServiceInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServiceInstanceInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServiceInstanceOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServiceOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServicePipelineInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServicePipelineOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServiceTemplateInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServiceTemplateOutput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServiceTemplateVersionInput' => [ 'base' => NULL, 'refs' => [], ], 'UpdateServiceTemplateVersionOutput' => [ 'base' => NULL, 'refs' => [], ], 'ValidationException' => [ 'base' => '<p>The input is invalid or an out-of-range value was supplied for the input parameter.</p>', 'refs' => [], ], ],];
